@@ -18,23 +18,33 @@
 #' createStudy("path/to/simulation")
 #' 
 #' }
-createStudy <- function(path, study_name = "my_study", antares_version = "7.0.0") {
+createStudy <- function(path, study_name = "my_study", antares_version = "8.0.0") {
+  antares_version <- as.numeric_version(antares_version)
   if (!dir.exists(path)) {
     dir.create(path = path, recursive = TRUE)
   } else {
     if (length(list.files(path = path)) > 0) {
       path <- file.path(path, study_name)
+      if (!dir.exists(path)) {
+        dir.create(path = path, recursive = TRUE)
+      }
     }
   }
-  if (antares_version < "6.5.0") {
+  if (antares_version < as.numeric_version("6.5.0")) {
     statut <- file.copy(
       from = list.files(path = system.file("newStudy", package = "antaresEditObject"), full.names = TRUE),
       to = path, recursive = TRUE
     )
     to_delete <- list.files(path = path, pattern = "ANTARESEDITOBJECT_TODELETE", full.names = TRUE, recursive = TRUE)
     unlink(to_delete)
+  } else if (antares_version < as.numeric_version("7.1.0")) {
+    statut <- unzip(zipfile = system.file("template-antares/antares-study-v700.zip", package = "antaresEditObject"), exdir = path)
+  } else if (antares_version < as.numeric_version("7.2.0")){
+    statut <- unzip(zipfile = system.file("template-antares/antares-study-v710.zip", package = "antaresEditObject"), exdir = path)
+  } else if (antares_version < as.numeric_version("8.0.0")){
+    statut <- unzip(zipfile = system.file("template-antares/antares-study-v720.zip", package = "antaresEditObject"), exdir = path)
   } else {
-    statut <- unzip(zipfile = system.file("template-antares/antares-study-v7.zip", package = "antaresEditObject"), exdir = path)
+    statut <- unzip(zipfile = system.file("template-antares/antares-study-v800.zip", package = "antaresEditObject"), exdir = path)
   }
   antares <- paste(readLines(con = file.path(path, "study.antares")), collapse = "\n")
   antares <- whisker::whisker.render(
